@@ -119,17 +119,19 @@ $messages = array(
 'subcategories'   => 'ކުދިގިސްމުތައް',
 'category-empty'  => "''މި ގިސްމުގައި އެއްވެއސް ސަފްހާ އެއް އަދި އެއްވެސް ފައިލެއް ނުހިމެނެއެވެ.''",
 
-'about'         => 'ތާރަފު',
-'article'       => 'ފިހުރިސްތު ޞަފްޙާ',
-'newwindow'     => '(އާ ވިންޑޯ އެއް ހުޅުވޭނެއެވެ)',
-'cancel'        => 'މަންސޫހު',
+'about'      => 'ތާރަފު',
+'article'    => 'ފިހުރިސްތު ޞަފްޙާ',
+'newwindow'  => '(އާ ވިންޑޯ އެއް ހުޅުވޭނެއެވެ)',
+'cancel'     => 'މަންސޫހު',
+'mytalk'     => 'މަގޭ ވާހަކަ',
+'navigation' => 'ސަމުގާ',
+'and'        => '&#32;އަދި',
+
+# Cologne Blue skin
 'qbfind'        => 'ހޯއްދަވާ',
 'qbedit'        => 'އުނިއިތުރުގެންނަވާ',
 'qbpageoptions' => 'މި ޞަފްޙާ',
 'qbmyoptions'   => 'މަގޭ ސަފްހާ ތައް',
-'mytalk'        => 'މަގޭ ވާހަކަ',
-'navigation'    => 'ސަމުގާ',
-'and'           => '&#32;އަދި',
 
 'errorpagetitle'    => 'ކުށް',
 'returnto'          => 'އަނބުރާ $1 އަށް ވަޑައިގަންނަވާ!',
@@ -165,7 +167,7 @@ $messages = array(
 'otherlanguages'    => 'އެހެން ބަސްބަހުން',
 'redirectedfrom'    => '(މިސްރާބުކުރެވުނީ $1 އިން)',
 'redirectpagesub'   => 'ޞަފްޙާގެ މިސްރާބު އައުކުރައްވާ',
-'lastmodifiedat'    => 'މި ޞަފްހާ އަށް އެންމެ ފަހުން ބަދަލެއް ގެނެވިފައިވަނީ $1، $2 ގައެވެ.', # $1 date, $2 time
+'lastmodifiedat'    => 'މި ޞަފްހާ އަށް އެންމެ ފަހުން ބަދަލެއް ގެނެވިފައިވަނީ $1، $2 ގައެވެ.',
 'protectedpage'     => 'ދިފާއުކުރެވިފައިވާ ޞަފްޙާ',
 'jumptosearch'      => 'ހޯއްދަވާ',
 
@@ -173,7 +175,6 @@ $messages = array(
 'aboutsite'            => 'ވިކިޕީޑިއާ ގެ ތާރަފު',
 'aboutpage'            => 'Project:ތާރަފު',
 'copyright'            => 'ހުރިހާ މާއްދާއެއް $1 ގެ ދަށުން ލިބެން އެބަހުއްޓެވެ.',
-'copyrightpagename'    => 'ވިކިޕީޑިއާ:ނަކަލުކުރުމުގެ ހައްގު',
 'copyrightpage'        => '{{ns:project}}:ނަކަލުކުރުމުގެހައްގު',
 'currentevents'        => 'ހިނގަމުންދާ ހާދިސާތައް',
 'disclaimers'          => 'އިއުލާނުތައް',
@@ -212,7 +213,6 @@ $messages = array(
 # Login and logout pages
 'welcomecreation'            => '== މަރުހަބާ، $1 ! ==
 ތިޔަބޭފުޅާގެ މެންބަރުޝިޕް ހެދިއްޖެއެވެ. ތިޔަ ބޭފުޅާގެ ވިކިޕީޑިއާގެ ތަރުޖީހުތައް ބަދަލުކުރައްވަން ހަނދުމަފުޅު ބަހައްޓަވާށެވެ.',
-'loginpagetitle'             => 'މެންބަރު ވެންނެވުން',
 'yourname'                   => 'މެންބަރުގެނަން',
 'yourpassword'               => 'ސިއްރުބަސް',
 'yourpasswordagain'          => 'ސިއްރުބަސް އަލުންލިޔުއްވާ',
@@ -224,12 +224,6 @@ $messages = array(
 'createaccount'              => 'މެންބަރަކަށް ވެ ވަޑައިގަންނަވާ',
 'badretype'                  => 'ތިޔަ ލިޔުއްވި ދެ ސިއްރުބަސް އެއް ސިއްރު ބަހާއި އަނެއް ސިއްރު ބަހާއި ދިމަލެއް ނުވޭ. އަދި ސިއްރުބަސް ރަނގަޅަށް ޖައްސަވާށެވެ!',
 'userexists'                 => 'ތިޔަ ލިޔުއްވި ނަން މިހާރުވެސް ދަނީ ބޭނުން ކުރެވެމުން، އައު ނަމެއް އިހުތިޔާރު ކުރައްވާ!',
-'youremail'                  => '٭ އީމޭލު',
-'username'                   => 'މެންބަރުނަން:',
-'yourrealname'               => '* އަސްލު ނަން',
-'yourlanguage'               => 'ބަސް:',
-'yournick'                   => 'ލަގަބު/ކުއްނިއްޔާ:',
-'email'                      => 'އީމޭލު',
 'wrongpassword'              => 'ތިޔަ ލިޔުއްވި ސިއްރުބަސް އަދި ރަނގަޅެއް ނޫނެވެ! އަދި މަސައްކަތް ކޮށްލައްވާށެވެ!',
 'wrongpasswordempty'         => 'ތިޔަ ލިޔުއްވި ސިއްރުބަހެއް ނޭނގުނު. އަލުން މަސައްކަތް ކޮށްލައްވާ!',
 'mailmypassword'             => 'ސިއްރުބަސް އީމޭލުކުރައްވާ',
@@ -290,7 +284,7 @@ $messages = array(
 'compareselectedversions' => 'އިހުތިޔާރު ކުރެވިފައިވާ ނުސްހާތައް އަޅައިކިޔުއްވާ',
 
 # Search results
-'viewprevnext'   => 'ބައްލަވާ($1) ($2) ($3).',
+'viewprevnext'   => 'ބައްލަވާ($1 {{int:pipe-separator}} $2) ($3).',
 'searchhelp-url' => 'Help:ފިހުރިސްތު',
 
 # Preferences page
@@ -298,10 +292,16 @@ $messages = array(
 'mypreferences'  => 'މަގޭ ތަރުޖީހުތައް',
 'changepassword' => 'ސިއްރުބަސް ބަދަލުކުރައްވާ',
 'columns'        => 'ކޮލަންތައް:',
-'files'          => 'ފައިލުތައް',
+'prefs-files'    => 'ފައިލުތައް',
+'youremail'      => '٭ އީމޭލު',
+'username'       => 'މެންބަރުނަން:',
+'yourrealname'   => '* އަސްލު ނަން',
+'yourlanguage'   => 'ބަސް:',
+'yournick'       => 'ލަގަބު/ކުއްނިއްޔާ:',
+'email'          => 'އީމޭލު',
 
 # User rights
-'userrights'               => 'މެންބަރުގެ ހައްގުތަކުގެ އިންތިޒާމް', # Not used as normal message but as header for the special page itself
+'userrights'               => 'މެންބަރުގެ ހައްގުތަކުގެ އިންތިޒާމް',
 'userrights-user-editname' => 'މެންބަރުނަން ލިޔުއްވާ:',
 
 # Recent changes
@@ -312,7 +312,9 @@ $messages = array(
 'show'              => 'ދައްކަވާ',
 
 # Recent changes linked
-'recentchangeslinked' => 'ގުޅުންހުރި ބަދަލުތައް',
+'recentchangeslinked'         => 'ގުޅުންހުރި ބަދަލުތައް',
+'recentchangeslinked-feed'    => 'ގުޅުންހުރި ބަދަލުތައް',
+'recentchangeslinked-toolbox' => 'ގުޅުންހުރި ބަދަލުތައް',
 
 # Upload
 'upload'            => 'ފައިލު ފޮނުވާ',
@@ -362,7 +364,9 @@ $messages = array(
 
 # Special:Categories
 'categories'         => 'ގިސްމުތައް',
-'categoriespagetext' => 'ތިރީގައި މިވާ ގިސްމުތައް ވިކީ ގައި މައުޖޫދުވެގެން ވެއެވެ.',
+'categoriespagetext' => 'ތިރީގައި މިވާ ގިސްމުތައް ވިކީ ގައި މައުޖޫދުވެގެން ވެއެވެ.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # E-mail user
 'emailuser' => 'މި މެންބަރަށް އީމޭލު ފޮނުއްވާ',
@@ -408,6 +412,8 @@ $messages = array(
 'contributions' => 'މެންބަރު ގެ ހިއްސާ',
 'mycontris'     => 'މަގޭ ހިއްސާ',
 
+'sp-contributions-userrights' => 'މެންބަރުގެ ހައްގުތަކުގެ އިންތިޒާމް',
+
 # What links here
 'whatlinkshere' => 'މިއާ ގުޅެނީ ކޮންއެއްޗެއް',
 
@@ -416,7 +422,7 @@ $messages = array(
 'ipbreason'         => 'ސަބަބު',
 'ipbsubmit'         => 'މި މެމްބަރާއި މެދު ފިޔަވަޅު އަޅުއްވާ!',
 'badipaddress'      => 'ނުރަނގަޅު އައި.ޕީ އެޑްރެހެއް',
-'expiringblock'     => 'މުއްދަތު ހަމަވާނީ $1',
+'expiringblock'     => 'މުއްދަތު ހަމަވާނީ $1 $2',
 'blocklink'         => 'ފިޔަވަޅުއަޅުއްވާ',
 'contribslink'      => 'ޙިއްޞާ',
 'proxyblocksuccess' => 'ފުރިހަމަވެއްޖެ.',
@@ -460,7 +466,7 @@ $messages = array(
 'exif-artist'           => 'މުސައްނިފު',
 'exif-filesource'       => 'ފައިލުގެ މަސްދަރު',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-n' => 'ތަސްވީރުގެ ސުރުހީ',
 
 # 'all' in various places, this might be different for inflected languages
@@ -475,7 +481,7 @@ $messages = array(
 'confirm_purge_button' => 'ރަނގަޅު',
 
 # Special:Version
-'version' => 'ނުސްހާ ނަމްބަރު', # Not used as normal message but as header for the special page itself
+'version' => 'ނުސްހާ ނަމްބަރު',
 
 # Special:SpecialPages
 'specialpages' => 'ހާއްސަ ޞަފްޙާތައް',
