@@ -14,21 +14,21 @@ $fallback = 'tr';
 
 $messages = array(
 # User preference toggles
-'tog-underline'               => 'Bınê girey de xete bıonce:',
+'tog-underline'               => 'Bınê girey de xete bonce:',
 'tog-highlightbroken'         => 'Gireunê thalu {a href="" class="new"}nia{/a} (alternatif: nia{a
-href="" class="internal"}?{/a}) bıasne.',
+href="" class="internal"}?{/a}) basne.',
 'tog-justify'                 => 'Paragrafu ayar ke',
 'tog-hideminor'               => 'Vurnaisunê senıku pela vurnaisunê peyênu de wedare',
 'tog-hidepatrolled'           => 'Vurnaisunê qontrolkerdu pela vurnaisê peyêni de wedare',
 'tog-newpageshidepatrolled'   => 'Pelunê qontrolkerdu lista pelunê newu de wedare',
-'tog-extendwatchlist'         => 'Lista şêrkerdene hira bıke ke vurnaişi pêro bıasê, teyna tewr peyêni nê',
+'tog-extendwatchlist'         => 'Lista şêrkerdene hira bıke ke vurnaişi pêro basê, teyna tewr peyêni nê',
 'tog-usenewrc'                => 'Vurnaisunê peyênunê hirakerdiu bıgurene (JavaScript lazımo)',
 'tog-numberheadings'          => 'Sernustu be ho numra cı sane',
-'tog-showtoolbar'             => 'Gozagunê hacetunê vurnaişi bıasne (JavaScript lazımo)',
+'tog-showtoolbar'             => 'Gozagunê hacetunê vurnaişi basne (JavaScript lazımo)',
 'tog-editondblclick'          => 'Pê dı rey teqnaene pele sero bıguriye (JavaScript lazımo)',
 'tog-editsection'             => 'Vurnaena qısımi ebe gireunê [bıvurne] ra feal ke',
 'tog-editsectiononrightclick' => 'Qısımu be teqnaena serrêze ra ebe gozaga raste bıvurne (JavaScript lazımo)',
-'tog-showtoc'                 => 'Tabloê tedeesteu bıasne (de pelunê be hirê sernustu ra zêdêri de)',
+'tog-showtoc'                 => 'Tabloê tedeesteu basne (de pelunê be hirê sernustu ra jêdêri de)',
 'tog-rememberpassword'        => 'Parola mı bia ho viri',
 'tog-editwidth'               => 'Warê nustey hira ke, ke verıniya pela cıdaena nustey tam baso',
 'tog-watchcreations'          => 'Pelê ke mı afernê, lista mına şêrkerdişi ke',
@@ -36,14 +36,14 @@ href="" class="internal"}?{/a}) bıasne.',
 'tog-watchmoves'              => 'Pelê ke mı kırısnê, lista mına şêrkerdişi ke',
 'tog-watchdeletion'           => 'Pelê ke mı esterıtê, lista mına şêrkerdişi ke',
 'tog-minordefault'            => 'Vurnaisunê ho pêrune ‘vurnaiso qızkek’ nisan bıde',
-'tog-previewontop'            => 'Verqayti pela nustene ser de bıasne',
-'tog-previewonfirst'          => 'Vurnaiso verên de verqayti tım bıasne',
+'tog-previewontop'            => 'Verqayti pela nustene ser de basne',
+'tog-previewonfirst'          => 'Vurnaiso verên de verqayti tım basne',
 'tog-nocache'                 => 'Pelunê cıcêraoği mia ho viri',
 'tog-enotifwatchlistpages'    => 'Pela ke ez şêr kenune eke vurnê mı rê e-poste bırusne',
 'tog-enotifusertalkpages'     => 'Pela mına hurênaişi ke vurnê mı rê e-poste bırusne',
 'tog-enotifminoredits'        => 'Vurnaisunê qızkeku de ki mı rê e-poste bırusne',
-'tog-enotifrevealaddr'        => 'Adresa e-postê mı postê xeberu de bıasne',
-'tog-shownumberswatching'     => 'Amorê karberunê şêrkerdoğu bıasne',
+'tog-enotifrevealaddr'        => 'Adresa e-postê mı postê xeberu de basne',
+'tog-shownumberswatching'     => 'Amorê karberunê şêrkerdoğu basne',
 'tog-oldsig'                  => 'Verqaytê imza mewcude:',
 'tog-fancysig'                => 'İmza rê mamelê wikimeqaley bıke (bê gireo otomatik)',
 'tog-externaleditor'          => 'Editorê teberi standart bıgurene (teyna serba ekspertuno, komputerê sıma de ayarê xısuşiy lazımê. [http://www.mediawiki.org/wiki/Manual:External_editors Melumato jêdêr.])',
@@ -58,8 +58,8 @@ href="" class="internal"}?{/a}) bıasne.',
 'tog-watchlisthideanons'      => 'Lista şêrkerdişi ra vurnaisunê karberunê anonimu wedare',
 'tog-watchlisthidepatrolled'  => 'Lista şêrkerdişi ra vurnaisunê qontrolkerdu wedare',
 'tog-ccmeonemails'            => 'E-postunê ke ez karberunê binu rê rusnenu, mı rê kopya inu bırusne',
-'tog-diffonly'                => 'Qıyasê versiyonu de tek ferqu bıasne, pela butıne nê',
-'tog-showhiddencats'          => 'Kategoriunê dızdêni bıasne',
+'tog-diffonly'                => 'Qıyasê versiyonu de tek ferqu basne, pela butıne nê',
+'tog-showhiddencats'          => 'Kategoriunê dızdêni basne',
 'tog-norollbackdiff'          => 'Peyserardene ra dıme ferqi caverde',
 
 'underline-always'  => 'Tım',
@@ -78,7 +78,7 @@ href="" class="internal"}?{/a}) bıasne.',
 'monday'        => 'Dıseme',
 'tuesday'       => 'Şêseme',
 'wednesday'     => 'Çarseme',
-'thursday'      => 'Phoncseme',
+'thursday'      => 'Phonseme',
 'friday'        => 'Yene',
 'saturday'      => 'Seme',
 'sun'           => 'Baz',
@@ -148,7 +148,7 @@ href="" class="internal"}?{/a}) bıasne.',
 'mainpagedocfooter' => "Serba melumatê gurenaena ''wiki software''i [http://meta.wikimedia.org/wiki/Help:Contents İdarê karberi] de mıracaet ke.
 
 == Gamê verêni ==
-* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Lista ayarunê vıraştene]
+* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Lista ayarunê vırastene]
 * [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki de ÇZP]
 * [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki ra lista serbest-daena postey]",
 
@@ -156,7 +156,7 @@ href="" class="internal"}?{/a}) bıasne.',
 'article'       => 'Pela tedeesteyu',
 'newwindow'     => '(zerrê pençerê dê newey de beno ra)',
 'cancel'        => 'Texelnaene',
-'moredotdotdot' => 'Zêde...',
+'moredotdotdot' => 'Jêde...',
 'mypage'        => 'Pela mı',
 'mytalk'        => 'Pela mına hurênaişi',
 'anontalk'      => "Pela hurênaisê ni ''IP''y",
@@ -273,8 +273,8 @@ $1',
 'edithelp'             => 'Phoştdariya vurnaişi',
 'edithelppage'         => 'Help:Pele çıturi vurnina',
 'helppage'             => 'Help:Tedeestey',
-'mainpage'             => 'Pelga Seri',
-'mainpage-description' => 'Pelga Seri',
+'mainpage'             => 'Pela Seri',
+'mainpage-description' => 'Pela seri',
 'policy-url'           => 'Project:Poliça',
 'portal'               => 'Portalê kome',
 'portal-url'           => 'Project:Portalê kome',
@@ -282,11 +282,11 @@ $1',
 'privacypage'          => 'Project:Madê dızdêni',
 
 'badaccess'        => 'Xeta desturi',
-'badaccess-group0' => 'Faeliyeto ke sıma wazenê, sıma nêşikinê ney ravêr berê.',
+'badaccess-group0' => 'Faeliyeto ke sıma wazenê, sıma nêşikinê ney raver berê.',
 'badaccess-groups' => 'No faeliyet teyna, keso ke {{PLURAL:$2|grube|grubu ra jüye}}: $1 dero, serba dino.',
 
-'versionrequired'     => 'MediaWiki ra vurnaisê $1i lazımo',
-'versionrequiredtext' => 'MediaWiki ra vurnaisê $1i lazımo ke na pele bıgurenê. Qaytê [[Special:Version|vurnaisê pele]] ke.',
+'versionrequired'     => 'MediaWiki ra vurnaisê $1 lazımo',
+'versionrequiredtext' => 'MediaWiki ra vurnaisê $1 lazımo ke na pele bıgurenê. Qaytê [[Special:Version|vurnaisê pele]] ke.',
 
 'ok'                      => 'Temam',
 'pagetitle-view-mainpage' => '',
@@ -302,19 +302,19 @@ $1',
 'editlink'                => 'bıvurne',
 'viewsourcelink'          => 'çıme bıvêne',
 'editsectionhint'         => 'Qısımê $1 bıvurne',
-'toc'                     => 'Tede estey',
-'showtoc'                 => 'bıasne',
+'toc'                     => 'Tedeestey',
+'showtoc'                 => 'basne',
 'hidetoc'                 => 'bınımne',
-'thisisdeleted'           => '$1i bıasne ya ki peyser biya?',
-'viewdeleted'             => '$1i bıasne?',
+'thisisdeleted'           => '$1i basne ya ki peyser biya?',
+'viewdeleted'             => '$1 basne?',
 'restorelink'             => '{{PLURAL:$1|jü vurnaiso esterıte|$1 vurnaisê esterıtey}}',
 'feedlinks'               => 'Cı de:',
 'feed-invalid'            => 'Aboneo nêvêrdoğ.',
-'feed-unavailable'        => 'Qutê sendikasyoni çino',
+'feed-unavailable'        => 'Weyikerdena sendikasyoni çina',
 'site-rss-feed'           => '$1 Weyikerdena RSSi',
 'site-atom-feed'          => '$1 Weyikerdena Atomi',
-'page-rss-feed'           => '"$1" RSS Qut',
-'page-atom-feed'          => '"$1" Qutê Atomi',
+'page-rss-feed'           => '"$1" Weyikerdena RSSi',
+'page-atom-feed'          => '"$1" Weyikerdena Atomi',
 'feed-atom'               => 'Atom',
 'feed-rss'                => 'RSS',
 'red-link-title'          => '$1 (pele çina)',
@@ -373,6 +373,7 @@ Kerem kerê, nae be namê ''URL''i jü [[Special:ListUsers/sysop|karber]]i ra va
 'readonly_lag'         => "Panga daeyu otomatikman qapan biye ''slave-database-servers''i ra be hata ''master''i",
 'internalerror'        => 'Xeta zerrey',
 'internalerror_info'   => 'Xeta zerrey: $1',
+'fileappenderrorread'  => 'İlawe ke bi "$1" nêşikiya bıwaniyo.',
 'fileappenderror'      => 'Dosya "$1"ine dosya "$2"ine ser nêbena.',
 'filecopyerror'        => 'Dosya "$1"i kopya nêbiye be dosya "$2".',
 'filerenameerror'      => 'Namê dosya "$1"i nêvuriya be dosya "$2".',
@@ -468,6 +469,7 @@ Nustena ho qonrol kerê, ya ki [[Special:UserLogin/signup|jü hesabo newe raker
 'nosuchusershort'         => 'Karberê do ebe namê "<nowiki>$1</nowiki>" çino.
 Nustena cı qontrol ke.',
 'nouserspecified'         => 'Gunê namê jü karberi bıdekernê.',
+'login-userblocked'       => 'No karber engel biyo. Cıkotene rê mısade cı nêdino.',
 'wrongpassword'           => 'Parola ğelete kota cı.
 Kerem ke, oncia bıcerrebne.',
 'wrongpasswordempty'      => 'Parola thale kota cı.
