@@ -19,29 +19,42 @@ $fallback = 'es';
 
 $messages = array(
 # User preference toggles
-'tog-underline'             => 'Subrayar linkes',
-'tog-highlightbroken'       => 'Mostrar los artículos vazíos <a href="" class="new">ansina</a> (alternativa: ansina<a href="" class="internal">?</a>).',
-'tog-justify'               => 'Atacanar paragrafos',
-'tog-hideminor'             => 'Esconde ediciones chiquiticas de los «trocamientos frescos»',
-'tog-hidepatrolled'         => 'Esconde los trocamientos "de guardia" en la hoja de los trocamientos frescos',
-'tog-newpageshidepatrolled' => 'Esconde las hojas cudiadas de la lista de hojas nuevas.',
-'tog-showtoolbar'           => 'Amostrár la barra de edision',
-'tog-editondblclick'        => 'Troca las hojas en klikando dos vezes. (JavaScript es menesteroso)',
-'tog-rememberpassword'      => 'Akodrár mis informasiones sobre ésta komputadóra',
-'tog-watchcreations'        => 'Ajusta las hojas que estó creando, a mi lista de escogidas',
-'tog-watchdefault'          => 'Ajusta las hojas que troco, a mi lista de escogidas',
-'tog-watchmoves'            => 'Ajusta las hojas que renombro, a mi lista de escogidas',
-'tog-watchdeletion'         => 'Ajusta las hojas que efasso, a mi lista de escogidas',
-'tog-minordefault'          => 'Va marcando todos los trocamientos como chiquiticos.',
-'tog-previewontop'          => 'Mostra la prevista arriba de la caxa del trocamiento.',
-'tog-previewonfirst'        => 'Mostra la prevista al primer trocamiento.',
-'tog-enotifwatchlistpages'  => 'Émbiame una letra electrónica cuando y ay un trocamiento en una hoja que estó cudiando',
-'tog-enotifusertalkpages'   => 'Embiame una pósta kuando troka mi pajina de diskusion de uzuario',
-'tog-enotifminoredits'      => 'Mándame también una letra electrónica por los trocamientos chiquiticos de las hojas.',
-'tog-shownumberswatching'   => 'Amostrár el número de uzuarios ke la vijilan',
-'tog-ccmeonemails'          => 'Las copias de las letras electrónicas que mandí a otros usuarios, ¡Mándamelas!',
-'tog-diffonly'              => 'No mostres el contenido de las hojas debaxo de las diferencias.',
-'tog-showhiddencats'        => 'Amostrár kategorías eskondidas',
+'tog-underline'               => 'Suliña los atamientos:',
+'tog-highlightbroken'         => 'Àmostra los artíkůlos vazíos <a href="" class="new">en kolorado</a> , (si no: este modo<a href="" class="internal">?</a>).',
+'tog-justify'                 => 'Àrrima los paraggrafos de dos vandas',
+'tog-hideminor'               => 'Eskonde los trokamientos chikitikos',
+'tog-hidepatrolled'           => 'Eskonde los trokamientos surveyados',
+'tog-newpageshidepatrolled'   => 'Eskonde las hojas surveyadas en la lista de las hojas muevas',
+'tog-extendwatchlist'         => 'Anchea mi lista de eskojidas afín de àmostrar todos los trokamientos, no sólo los muevos',
+'tog-usenewrc'                => 'Usa el modo adelantado (JavaScript es menester)',
+'tog-numberheadings'          => 'Numerota los títůlos de una manera otomatika',
+'tog-showtoolbar'             => 'Àmostra el chibuk de aparatos (JavaScript es menester)',
+'tog-editondblclick'          => 'Troka los hojas en doble klik. (JavaScript es menester)',
+'tog-editsection'             => 'Ofre la possibilidad de trokar los kapítůlos usando el atamiento [troka]',
+'tog-editsectiononrightclick' => 'Ofrir la possibbilidad de trocar los capítůlos; en pizando el botón derecho del ratón, cuando está encima de los títůlos de capítůlos (JavaScript es menesteroso)',
+'tog-showtoc'                 => 'Amostrar el tabblo de contenidos (por las hojas que tienen más de 3 títůlos)',
+'tog-rememberpassword'        => 'Akodrár mis informasiones sobre ésta komputadóra',
+'tog-editwidth'               => 'Alargar la caxa de trocamiento para inchir el ekran entero',
+'tog-watchcreations'          => 'Ajustar las hojas que crií, a mi lista de escogidas',
+'tog-watchdefault'            => 'Ajustar las hojas que troquí, a mi lista de escogidas',
+'tog-watchmoves'              => 'Ajustar las hojas que taxireí, a mi lista de escogidas',
+'tog-watchdeletion'           => 'Ajustar las hojas que efassí, a mi lista de escogidas',
+'tog-minordefault'            => 'Va marcando todos los trocamientos como chiquiticos.',
+'tog-previewontop'            => 'Amostrar la prēvizibbilizasyón enriba de la caxa de ēddisyón',
+'tog-previewonfirst'          => 'Amostrar la prēvizibbilizasyón al primer trocamiento',
+'tog-nocache'                 => 'No permeter a la kaxé de las hojas',
+'tog-enotifwatchlistpages'    => 'Embiarme un e-mail (una letra elektronika) cuando se troca una hoja que está en mi lista de escogidos',
+'tog-enotifusertalkpages'     => 'Embiarme un e-mail (una letra elektronika) cuando se troca mi hoja de diskusyón',
+'tog-enotifminoredits'        => 'También mandarme un e-mail (una letra elektronika) por los trocamientos chiquiticos de las hojas',
+'tog-enotifrevealaddr'        => 'Amostrar mi addresso de e-mail (letra elektronika) en los e-mailes de aviso',
+'tog-shownumberswatching'     => 'Amostrar el número de usadores que la cudian',
+'tog-oldsig'                  => 'Prēvizibbilizasyón de la firma que ya egziste:',
+'tog-fancysig'                => 'Tratar la firma como si era vikiteksto (sin un link otomatik)',
+'tog-externaleditor'          => 'Usar un ēdditor de afuera (sólo por los sabericios, tu bilgisayar/orddênador tiene menester de arreglamientos especiales por esto)',
+'tog-externaldiff'            => "Usar un ''diff'' de afuera (sólo por los sabericios, tu bilgisayar/orddênador tiene menester de arreglamientos especiales por esto)",
+'tog-ccmeonemails'            => 'Las copias de las letras electrónicas que mandí a otros usuarios, ¡Mándamelas!',
+'tog-diffonly'                => 'No mostres el contenido de las hojas debaxo de las diferencias.',
+'tog-showhiddencats'          => 'Amostrár kategorías eskondidas',
 
 'underline-always' => 'Siempre',
 'underline-never'  => 'Nunka',
@@ -105,27 +118,55 @@ $messages = array(
 'category-media-header'    => 'Archivos multimedia en la kategoría "$1"',
 'category-empty'           => "''La kategoría no kontiene aktualmente ningún artikolo o archivo multimedia''",
 'hidden-categories'        => '{{PLURAL:$1|Categoría escondida|Categorías escondidas}}',
-'hidden-category-category' => 'Categorías escondidas', # Name of the category where hidden categories will be listed
+'hidden-category-category' => 'Categorías escondidas',
 'category-subcat-count'    => '{{PLURAL:$2|Esta categoría contiene solamente la categoría venidera.|Esta categoría contiene {{PLURAL:$1|las categorías venideras|$1 subcategorías venideras}}, de un total de $2 subcategorías.}}',
 'category-article-count'   => '{{PLURAL:$2|Esta categoría contiene solamente la hoja venidera.|{{PLURAL:$1|La hoja venidera apartiene|Las $1 hojas venideras apartienen}} a esta categoría, de un total de $2.}}',
 'listingcontinuesabbrev'   => 'cont.',
 
-'about'          => 'Encima de',
-'article'        => 'Artícůlo',
-'newwindow'      => '(Se avre en una ventana nueva)',
-'cancel'         => 'Suprimir',
+'about'         => 'Encima de',
+'article'       => 'Artícůlo',
+'newwindow'     => '(Se avre en una ventana nueva)',
+'cancel'        => 'Suprimir',
+'moredotdotdot' => 'Mas...',
+'mypage'        => 'Mi hoja',
+'mytalk'        => 'Mi diskusyón',
+'anontalk'      => 'Diskusion para esta IP',
+'navigation'    => 'Passeo',
+'and'           => '&#32;i',
+
+# Cologne Blue skin
 'qbfind'         => 'Topa',
 'qbbrowse'       => 'Navêga',
 'qbedit'         => 'Troca',
 'qbpageoptions'  => 'Opciones de la hoja',
 'qbmyoptions'    => 'Mis opsiones',
 'qbspecialpages' => 'Pajinas espesiales',
-'moredotdotdot'  => 'Mas...',
-'mypage'         => 'Mi hoja',
-'mytalk'         => 'Mi diskusyón',
-'anontalk'       => 'Diskusion para esta IP',
-'navigation'     => 'Passeo',
-'and'            => '&#32;i',
+'faq'            => 'FAQ',
+'faqpage'        => 'Project:FAQ',
+
+# Vector skin
+'vector-action-delete'       => 'Efassa',
+'vector-action-move'         => 'Taxirea',
+'vector-action-protect'      => 'Guarda',
+'vector-namespace-category'  => 'Kateggoría',
+'vector-namespace-help'      => 'Hoja de ayudo',
+'vector-namespace-image'     => 'Dosya',
+'vector-namespace-main'      => 'Hoja',
+'vector-namespace-media'     => 'Hoja de multimedya',
+'vector-namespace-mediawiki' => 'Noticia',
+'vector-namespace-project'   => 'Hoja de proyecto',
+'vector-namespace-special'   => 'Hoja especial',
+'vector-namespace-talk'      => 'Diskussión',
+'vector-namespace-template'  => 'Xabblón',
+'vector-namespace-user'      => 'Hoja de empleador',
+'vector-view-create'         => 'Cria',
+'vector-view-edit'           => 'Troca',
+'vector-view-history'        => 'Ve la istoria',
+'vector-view-view'           => 'Melda',
+'vector-view-viewsource'     => 'Ve su orijín',
+'actions'                    => 'Acciones',
+'namespaces'                 => 'Espacios de nombres',
+'variants'                   => 'Variantes',
 
 'errorpagetitle'    => 'Yerro',
 'returnto'          => 'Tornar a $1.',
@@ -147,7 +188,7 @@ $messages = array(
 'create-this-page'  => 'Cria esta hoja',
 'delete'            => 'Efassa',
 'deletethispage'    => 'Efassa esta hoja',
-'undelete_short'    => 'Abolta $1 trocamientos',
+'undelete_short'    => 'Abolta $1 {{PLURAL:$1|trocamientos|trocamientos}}',
 'protect'           => 'Abriga',
 'protect_change'    => 'Troca el abrigamiento',
 'protectthispage'   => 'Abriga esta hoja',
@@ -155,7 +196,7 @@ $messages = array(
 'unprotectthispage' => 'Desabriga esta hoja',
 'newpage'           => 'Hoja nueva',
 'talkpage'          => 'Diskute la hoja',
-'talkpagelinktext'  => 'Message',
+'talkpagelinktext'  => 'Messaje',
 'specialpage'       => 'Hoja Especial',
 'personaltools'     => 'Aparatos personales',
 'postcomment'       => 'Ajusta un comentario',
@@ -174,7 +215,7 @@ $messages = array(
 'otherlanguages'    => 'En otras linguas',
 'redirectedfrom'    => '(Redirigido desde $1)',
 'redirectpagesub'   => 'Hoja redirigida',
-'lastmodifiedat'    => 'Esta hoja fue trocada por la última vez en $2, a las $1.', # $1 date, $2 time
+'lastmodifiedat'    => 'Esta hoja fue trocada por la última vez en $2, a las $1.',
 'protectedpage'     => 'Hoja guardada',
 'jumpto'            => 'Salta a:',
 'jumptonavigation'  => 'passeo',
@@ -191,15 +232,14 @@ $messages = array(
 'disclaimerpage'       => 'Project:Rēfusamiento de responsabbilitá general',
 'edithelp'             => '¿Cómodo se la troca?',
 'edithelppage'         => 'Help:Una hoja, ¿cómodo se la troca?',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
 'helppage'             => 'Help:Contenidos',
 'mainpage'             => 'La Primera Hoja',
 'mainpage-description' => 'La Hoja Primera',
 'policy-url'           => 'Project:Politikas',
 'portal'               => 'Portal de la comunidad',
-'privacy'              => 'Prencipio de particolaridad',
-'privacypage'          => 'Project:Prencipio de particolaridad',
+'portal-url'           => 'Project:Portal de la comunidad',
+'privacy'              => 'Prencipio de particůlaridad',
+'privacypage'          => 'Project:Prencipio de particůlaridad',
 
 'badaccess' => 'Yerro de permissión',
 
@@ -235,7 +275,7 @@ $messages = array(
 'nstab-mediawiki' => 'Messaj',
 'nstab-template'  => 'Xabblón',
 'nstab-help'      => 'Ayudo',
-'nstab-category'  => 'Categoría',
+'nstab-category'  => 'Kateggoría',
 
 # Main script and global functions
 'nosuchspecialpage' => 'No ay tala hoja especial',
@@ -273,10 +313,7 @@ Puede ser que contiene uno o más caracteres que no se pueden usar en los títul
 'createaccountmail'       => 'por una letra electrónica',
 'userexists'              => 'El nombre que entrates ya se usa.
 Si puede ser, escoge un otro nombre.',
-'youremail'               => 'El adderesso de tu letra electrόnica:',
-'username'                => 'Nombre de usuario:',
-'yourlanguage'            => 'Lingua:',
-'email'                   => 'Letra electrónica',
+'createaccounterror'      => 'No se pudo crear el cuento: $1',
 'mailmypassword'          => 'Embiar una nueva koddiche por e-mail',
 'emailconfirmlink'        => 'Confirma su adderesso de letra electrónica',
 'accountcreated'          => 'Cuento creado',
@@ -335,6 +372,8 @@ o [{{fullurl:{{FULLPAGENAME}}|action=edit}} trocar esta hoja]</span>.',
 'yourtext'                         => 'Tu teksto',
 'yourdiff'                         => 'Diferencias',
 'copyrightwarning'                 => "Si puede ser, observa que todas las contribuciones a {{SITENAME}} se consideran hechas públicas abaxo la $2 (ver detalyos en $1). Si no queres que la gente endereche tus tekstos escritos sin piadad i los esparta libberamente, alora no los metas aquí. También nos estás asegurando ansí que escribites este teksto tu mismo i sos el dueño de los derechos de autor, o lo copiates desde el dominio público u otra fuente libbero.'''¡QUE N0 USES TEKSTOS ESCRITOS CON COPYRIGHT SIN PERMISSIÓN!'''<br />",
+'templatesused'                    => '{{PLURAL:$1|El xabblón usado|Los xabblones usados}} en esta hoja:',
+'templatesusedpreview'             => '{{PLURAL:$1|El xabblón usado|Los xabblones usados}} en esta vista:',
 'template-protected'               => '(guardada)',
 'template-semiprotected'           => '(media guardada)',
 'hiddencategories'                 => 'Esta hoja es un miembro de {{PLURAL:$1|1 kateggoría escondida|$1 kateggorías escondidas}}:',
@@ -343,7 +382,8 @@ o [{{fullurl:{{FULLPAGENAME}}|action=edit}} trocar esta hoja]</span>.',
 
 # History pages
 'viewpagelogs'           => 'Ver los registros de esta hoja',
-'revisionasof'           => 'Rêvizión de $1',
+'currentrev-asof'        => 'Versión de alcabo de $1',
+'revisionasof'           => 'Rēvisión de $1',
 'previousrevision'       => '← Rēvisión de antes',
 'nextrevision'           => 'Rêvisión venidera →',
 'currentrevisionlink'    => 'Revisión actual',
@@ -355,16 +395,23 @@ o [{{fullurl:{{FULLPAGENAME}}|action=edit}} trocar esta hoja]</span>.',
 Leyenda: (act) = diferencias con la versión actual,
 (prev) = diferencias con la versión previa, M = edición menor",
 'history-fieldset-title' => 'Buscar en la istoria',
+'history-show-deleted'   => 'Sólamente efassado',
 'histfirst'              => 'Primeras',
 'histlast'               => 'De alcabo',
 'historysize'            => '({{PLURAL:$1|1 byte|$1 bytes}})',
 'historyempty'           => '(vazío)',
 
 # Revision deletion
-'rev-delundel'      => 'mostra/esconde',
-'revdelete-log'     => 'La razón para efassar:',
-'revdel-restore'    => 'Troca la viźibbilidad',
-'revdelete-content' => 'contenido',
+'rev-delundel'               => 'mostra/esconde',
+'rev-showdeleted'            => 'mostra',
+'revdelete-show-file-submit' => 'Sí',
+'revdelete-radio-same'       => '(no troques)',
+'revdelete-radio-set'        => 'Sí',
+'revdelete-radio-unset'      => 'No',
+'revdelete-log'              => 'Razón:',
+'revdel-restore'             => 'Troca la viźibbilidad',
+'revdelete-content'          => 'contenido',
+'revdelete-reasonotherlist'  => 'Otra razón',
 
 # History merging
 'mergehistory-reason' => 'Razón:',
@@ -387,10 +434,12 @@ Leyenda: (act) = diferencias con la versión actual,
 'searchsubtitleinvalid'     => "Buscates '''$1'''",
 'notitlematches'            => 'No se pudo topar en dingún título.',
 'notextmatches'             => 'No se pudo topar en dinguna hoja.',
+'prevn'                     => '{{PLURAL:$1|$1}} de antes',
+'nextn'                     => '{{PLURAL:$1|$1}} venideras',
 'prevn-title'               => '$1 {{PLURAL:$1|resultado|resultados}} de antes',
 'nextn-title'               => 'Venideros $1 {{PLURAL:$1|resultado|resultados}}',
 'shown-title'               => 'Mostra $1 {{PLURAL:$1|resultado|resultados}} por hoja',
-'viewprevnext'              => 'Ver ($1) ($2) ($3).',
+'viewprevnext'              => 'Ver ($1 {{int:pipe-separator}} $2) ($3).',
 'searchhelp-url'            => 'Help:Ayudo',
 'searchprofile-everything'  => 'Todo',
 'searchprofile-advanced'    => 'Adelantado',
@@ -413,21 +462,30 @@ Las búsquedas producen más o munco a buscar biervos comunes como «la» o «de
 'powersearch-ns'            => 'Busca en los espacios de nombres:',
 'powersearch-redir'         => 'Mostra las redirecciones',
 'powersearch-field'         => 'Busca por',
+'powersearch-toggleall'     => 'Todos',
 'search-external'           => 'Búsqueda eksterna',
 
 # Preferences page
 'preferences'               => 'Preferencias',
 'mypreferences'             => 'Mis preferencias',
+'prefs-skin'                => 'Vista',
+'prefs-math'                => 'Fórmulas',
 'prefs-rc'                  => 'Los Trocamientos de Alcabo',
 'prefs-watchlist'           => 'Lista de los Trocamientos Preferidos',
 'prefs-watchlist-days'      => 'El número de los días a mostrar en la lista de los trocamientos preferidos:',
+'prefs-watchlist-days-max'  => '7 días a lo más muncho',
 'prefs-resetpass'           => 'Trocar la parola',
+'prefs-rendering'           => 'Vista',
 'timezoneregion-africa'     => 'África',
 'timezoneregion-america'    => 'América',
 'timezoneregion-antarctica' => 'Antárctica',
 'timezoneregion-asia'       => 'Asia',
 'timezoneregion-australia'  => 'Ostralia',
 'timezoneregion-europe'     => 'Europa',
+'youremail'                 => 'El adderesso de tu letra electrόnica:',
+'username'                  => 'Nombre de usuario:',
+'yourlanguage'              => 'Lingua:',
+'email'                     => 'Letra electrónica',
 
 # Groups
 'group-sysop' => 'Administradores',
@@ -472,6 +530,8 @@ Las búsquedas producen más o munco a buscar biervos comunes como «la» o «de
 
 # Recent changes linked
 'recentchangeslinked'         => 'Trocamientos conectados',
+'recentchangeslinked-feed'    => 'Trocamientos conectados',
+'recentchangeslinked-toolbox' => 'Trocamientos conectados',
 'recentchangeslinked-title'   => 'Los trocamientos relacionados con "$1"',
 'recentchangeslinked-summary' => "La lista dêbbaxo, es la lista de los trocamientos de alcabo, por las hojas que dan link a la hoja siñalada (o por los miembros de la kateggoría siñalada).
 Las hojas en tu [[Special:Watchlist|lista de escogidas]] son escritas '''gordas'''.",
@@ -488,17 +548,19 @@ Las hojas en tu [[Special:Watchlist|lista de escogidas]] son escritas '''gordas'
 'listfiles_user' => 'Usuario',
 
 # File description page
+'file-anchor-link'          => 'Archivo',
 'filehist'                  => 'Istoria del dosyé',
 'filehist-help'             => 'Klika encima de una data/ora para vel el arxivo de esta data.',
 'filehist-current'          => 'actual',
 'filehist-datetime'         => 'Data/Ora',
 'filehist-thumb'            => 'Miniatura',
+'filehist-thumbtext'        => 'Miniatura de la versión de $1',
 'filehist-user'             => 'Empleador',
 'filehist-dimensions'       => 'Dimensiones',
 'filehist-comment'          => 'Comentario',
 'imagelinks'                => 'Linkes al arxivo multimedia',
 'linkstoimage'              => '{{PLURAL:$1|La hoja venidera da link|Las hojas venideras dan link}} a este arxivo:',
-'sharedupload'              => 'Este arxivo es de $1 i puede ser usado por otros proyectos.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
+'sharedupload'              => 'Este arxivo es de $1 i puede ser usado por otros proyectos.',
 'uploadnewversion-linktext' => 'Subir una nueva versión de este arxivo',
 
 # Random page
@@ -543,7 +605,7 @@ Las hojas en tu [[Special:Watchlist|lista de escogidas]] son escritas '''gordas'
 'special-categories-sort-abc'   => 'ordenar alefbeticamente',
 
 # Special:LinkSearch
-'linksearch' => '↓ Linkes eksternos',
+'linksearch' => 'Linkes eksternos',
 
 # Special:Log/newusers
 'newuserlogpage'          => 'Registro de creación de usuarios',
@@ -587,7 +649,7 @@ resultados, i que lo estás haziendo de acorddo con las [[{{MediaWiki:Policy-url
 Mira $2 para un registro de los efassados nuevos.',
 'deletedarticle'        => 'efassó «[[$1]]»',
 'dellogpage'            => 'Registro de efassados',
-'deletecomment'         => 'La razón de efassar:',
+'deletecomment'         => 'Razón:',
 'deleteotherreason'     => 'Otra razón:',
 'deletereasonotherlist' => 'Otra razón',
 'deletereason-dropdown' => '* Motivos generales de efassamientos
@@ -642,6 +704,7 @@ A continuación se mostran las opciones actuales de la hoja '''$1''':",
 
 'sp-contributions-newbies'  => 'Mostrar solo las ajustamientos de los usuarios nuevos',
 'sp-contributions-blocklog' => 'registro de bloqueos',
+'sp-contributions-talk'     => 'Diścutir',
 'sp-contributions-search'   => 'Buscar ajustamientos',
 'sp-contributions-username' => 'Dirección IP o nombre de usuario:',
 'sp-contributions-submit'   => 'Buscar',
@@ -664,7 +727,7 @@ A continuación se mostran las opciones actuales de la hoja '''$1''':",
 
 # Block/unblock
 'blockip'                  => 'Bloquear usuario',
-'ipboptions'               => '2 oras:2 hours,1 día:1 day,3 días:3 days,1 semana:1 week,2 semanas:2 weeks,1 mes:1 month,3 meses:3 months,6 meses:6 months,1 año:1 year,para siempre:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 oras:2 hours,1 día:1 day,3 días:3 days,1 semana:1 week,2 semanas:2 weeks,1 mes:1 month,3 meses:3 months,6 meses:6 months,1 año:1 year,para siempre:infinite',
 'ipblocklist'              => 'Lista de direcciones IP y nombres de usuario bloqueadas',
 'blocklink'                => 'Bloquea',
 'unblocklink'              => 'quita el bloqueo',
@@ -699,7 +762,7 @@ En estos casos, va deber trasladar manualmente el contenido de la hoja de diskus
 'move-watch'       => 'Cudiar este artículo',
 'movepagebtn'      => 'Renombra la hoja',
 'pagemovedsub'     => 'Renombrado realizado con reuxitá',
-'movepage-moved'   => '\'\'\'"$1" fue renombrado a "$2".\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => '\'\'\'"$1" fue renombrado a "$2".\'\'\'',
 'articleexists'    => 'Una hoja con este nombre ya egziste, o el nombre que escogites no es valable.
 Si puede ser, escoge otro nombre.',
 'talkexists'       => 'La hoja fue renombrada con reuxito, ma la diskussión no se pudo renombrar porque ya egziste una en el título nuevo. Si puede ser, házelo manualmente.',
@@ -708,7 +771,7 @@ Si puede ser, escoge otro nombre.',
 '1movedto2'        => 'El nuevo nombre de la hoja [[$1]]; agora es [[$2]]',
 '1movedto2_redir'  => 'El títůlo [[$1]] fue reddireksyonado a la hoja [[$2]]',
 'movelogpage'      => 'Registro de traslados',
-'movereason'       => 'Razόn',
+'movereason'       => 'Razón:',
 'revertmove'       => 'abolta',
 
 # Export
@@ -732,7 +795,7 @@ Si puede ser, escoge otro nombre.',
 'tooltip-pt-login'                => 'Se le aconseja a entrar, ma no es obligado.',
 'tooltip-pt-logout'               => 'Salir de la sessión',
 'tooltip-ca-talk'                 => 'Diskusyón encima del artícůlo',
-'tooltip-ca-edit'                 => 'Puedes trocar esta hoja 
+'tooltip-ca-edit'                 => 'Puedes trocar esta hoja
 Si puede ser, usa el botón de prēviźualiźasyón antes de enrejjistrarla.',
 'tooltip-ca-addsection'           => 'Empeça una nueva sección',
 'tooltip-ca-viewsource'           => 'Esta hoja está guardada; sólo puedes ver su codd fuente',
@@ -746,13 +809,14 @@ Si puede ser, usa el botón de prēviźualiźasyón antes de enrejjistrarla.',
 'tooltip-search-go'               => 'Si ay una hoja con este nombre egzakto, vate allá.',
 'tooltip-search-fulltext'         => 'Busca este teksto en las hojas',
 'tooltip-n-mainpage'              => 'Torna a la Hoja Primera',
+'tooltip-n-mainpage-description'  => 'Visita la Primera Hoja',
 'tooltip-n-portal'                => 'Encima del prodjekto, ¿qué se puede hazer i ánde topar todo?',
 'tooltip-n-currentevents'         => 'Topar informaciones encima de los acontecimientos actuales',
 'tooltip-n-recentchanges'         => 'La lista de los trocamientos frescos en el viki',
 'tooltip-n-randompage'            => 'Carga una hoja por ventura',
 'tooltip-n-help'                  => 'El lugar para ambezarse',
 'tooltip-t-whatlinkshere'         => 'La lista de todas las hojas del viki que se atan con ésta',
-'tooltip-t-recentchangeslinked'   => 'Los trocamientos de alcabo de las hojas linkados desde aquí',
+'tooltip-t-recentchangeslinked'   => 'Los trocamientos de alcabo de las hojas linkeados desde aquí',
 'tooltip-feed-rss'                => 'Sindicación RSS de esta hoja',
 'tooltip-feed-atom'               => 'Sindicación Atom de esta hoja',
 'tooltip-t-contributions'         => 'Ver la lista de ajustamientos de este usuario',
@@ -764,7 +828,7 @@ Si puede ser, usa el botón de prēviźualiźasyón antes de enrejjistrarla.',
 'tooltip-ca-nstab-main'           => 'Ve el artículo',
 'tooltip-ca-nstab-user'           => 'Ve la hoja de usuario',
 'tooltip-ca-nstab-special'        => 'Esta es una hoja especial, la hoja ya no se puede trocar',
-'tooltip-ca-nstab-project'        => 'Ver la hoja del proyecto',
+'tooltip-ca-nstab-project'        => 'Ver la hoja del prodjekto',
 'tooltip-ca-nstab-image'          => 'Ver la hoja de la image.',
 'tooltip-ca-nstab-template'       => 'Ver el xabblón',
 'tooltip-ca-nstab-category'       => 'Ve la hoja de categoría',
@@ -812,7 +876,7 @@ Los otros campos se van a guardar por defecto.
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength',
 
 # EXIF tags
 'exif-filesource'   => 'Manadéro de archivo',
@@ -824,7 +888,7 @@ Los otros campos se van a guardar por defecto.
 'exif-lightsource-9'  => 'Bueno tiémpo',
 'exif-lightsource-10' => 'Tiémpo nuvlozo',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => 'Kilometros por óra',
 
 # External editor support
@@ -876,10 +940,10 @@ Los otros campos se van a guardar por defecto.
 'watchlisttools-raw'  => 'Troca tu lista de escogidas en crudo',
 
 # Special:Version
-'version'                  => 'Versión', # Not used as normal message but as header for the special page itself
+'version'                  => 'Versión',
 'version-specialpages'     => 'Pajinas espesiales',
 'version-other'            => 'Otros',
-'version-version'          => 'Versión',
+'version-version'          => '(Versión $1)',
 'version-software-version' => 'Versión',
 
 # Special:FileDuplicateSearch
