@@ -1138,7 +1138,7 @@ $messages = array(
 'badipaddress'             => 'Άχρηστον IP',
 'blockipsuccesssub'        => "Τ' ασπάλιγμαν εγέντον",
 'ipb-edit-dropdown'        => 'Άλλαξον αιτίας ασπαλιγματί',
-'ipblocklist'              => 'Ασπαλιγμένα IP και λογαρίας',
+'ipblocklist'              => 'Ασπαλιγμένα λογαρίας',
 'ipblocklist-submit'       => 'Εύρον',
 'infiniteblock'            => 'άπειρον',
 'blocklink'                => 'Ασπάλιγμαν',
