@@ -76,7 +76,7 @@ $messages = array(
 'tog-justify'            => 'Justifika parágrafu sira',
 'tog-hideminor'          => "Lá'os hatudu muda ki-ki'ik iha mudansa foufoun sira",
 'tog-usenewrc'           => 'Uza lista "Mudansa foufoun sira" di\'ak liu (JavaScript)',
-'tog-showtoolbar'        => 'Hatudu kaixa edita (JavaScript)',
+'tog-showtoolbar'        => 'Hatudu kaixa edita (presiza JavaScript)',
 'tog-watchcreations'     => "Hateke pájina sira-ne'ebé ha'u kria",
 'tog-watchdefault'       => "Hateke pájina sira-ne'ebé ha'u edita",
 'tog-watchmoves'         => "Hateke pájina sira-ne'ebé ha'u book",
@@ -238,7 +238,7 @@ $messages = array(
 'privacy'              => 'Polítika privasidade nian',
 'privacypage'          => 'Project:Polítika privasidade nian',
 
-'badaccess'        => 'Sala priviléjiu nian',
+'badaccess'        => 'Ita la iha permisaun...',
 'badaccess-group0' => "Ó la bele halo ne'e.",
 'badaccess-groups' => "Ba halo ne'e tenke iha {{PLURAL:$2|lubu|lubu ida husi}} $1.",
 
@@ -324,28 +324,31 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'media_sample' => 'Ezemplu.ogg',
 
 # Edit pages
-'minoredit'              => "Ne'e muda ki'ik",
-'watchthis'              => "Hateke pájina ne'e",
-'savearticle'            => 'Filak pájina',
-'showdiff'               => 'Hatudu diferensa sira',
-'anoneditwarning'        => 'Ó lá\'os "log-in" iha momentu.',
-'blockedtitle'           => "Uza-na'in la bele edita (blokeiu)",
-'blockednoreason'        => 'laiha motivu',
-'whitelistedittext'      => 'Ó tenke $1 ba edita pájina sira.',
-'loginreqpagetext'       => 'Ó tenke $1 ba haree pájina seluk.',
-'newarticle'             => '(Foun)',
-'noarticletext'          => "Iha momentu lá'os testu iha pájina ne'e, bele [[Special:Search/{{PAGENAME}}|buka naran pájina nian]] iha pájina seluk, <span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs], ka [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita pájina ne'e]</span>.",
-'editing'                => 'Edita $1',
-'editingsection'         => 'Edita $1 (seksaun)',
-'editingcomment'         => 'Edita $1 (seksaun foun)',
-'yourtext'               => 'Ó-nia testu',
-'yourdiff'               => 'Diferensa sira',
-'template-protected'     => '(proteje tiha)',
-'template-semiprotected' => '(proteje tiha balun)',
-'nocreatetext'           => "Ó la bele kria pájina foun iha {{SITENAME}}.
+'minoredit'                        => "Ne'e muda ki'ik",
+'watchthis'                        => "Hateke pájina ne'e",
+'savearticle'                      => 'Filak pájina',
+'showdiff'                         => 'Hatudu diferensa sira',
+'anoneditwarning'                  => 'Ó lá\'os "log-in" iha momentu.',
+'blockedtitle'                     => "Uza-na'in la bele edita (blokeiu)",
+'blockednoreason'                  => 'laiha motivu',
+'whitelistedittext'                => 'Ó tenke $1 ba edita pájina sira.',
+'loginreqpagetext'                 => 'Ó tenke $1 ba haree pájina seluk.',
+'newarticle'                       => '(Foun)',
+'noarticletext'                    => "Iha momentu lá'os testu iha pájina ne'e, bele [[Special:Search/{{PAGENAME}}|buka naran pájina nian]] iha pájina seluk, <span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs], ka [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita pájina ne'e]</span>.",
+'previewnote'                      => "'''Ne'e de'it pájina ba kontrola; Ita-nia mudansa la armazenadu seidauk!'''",
+'editing'                          => 'Edita $1',
+'editingsection'                   => 'Edita $1 (seksaun)',
+'editingcomment'                   => 'Edita $1 (seksaun foun)',
+'yourtext'                         => 'Ó-nia testu',
+'yourdiff'                         => 'Diferensa sira',
+'template-protected'               => '(proteje tiha)',
+'template-semiprotected'           => '(proteje tiha balun)',
+'hiddencategories'                 => "Pájina ne'e iha {{PLURAL:$1|kategoria ida-ne'ebé subar|kategoria $1 sira-ne'ebé subar}}:",
+'nocreatetext'                     => "Ó la bele kria pájina foun iha {{SITENAME}}.
 Ó bele edita pájina sira-ne'ebé {{SITENAME}} iha ona ka [[Special:UserLogin|log in ka kria konta uza-na'in]].",
-'nocreate-loggedin'      => 'Ó la bele kria pájina foun.',
-'permissionserrorstext'  => "Ó la bele halo ne'e; {{PLURAL:$1|motivu|motivu sira}}:",
+'nocreate-loggedin'                => 'Ó la bele kria pájina foun.',
+'permissionserrorstext'            => "Ó la bele halo ne'e; {{PLURAL:$1|motivu|motivu sira}}:",
+'permissionserrorstext-withaction' => 'Ita la bele $2. {{PLURAL:$1|Razaun|Razaun sira}}:',
 
 # Account creation failure
 'cantcreateaccounttitle' => "La bele registrar uza-na'in",
@@ -378,10 +381,12 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'lineno' => 'Liña $1:',
 
 # Search results
+'searchsubtitleinvalid'     => "Ita buka tiha ona '''$1'''",
 'prevn'                     => 'molok {{PLURAL:$1|$1}}',
 'nextn'                     => 'oinmai {{PLURAL:$1|$1}}',
 'viewprevnext'              => 'Haree ($1 {{int:pipe-separator}} $2) ($3)',
 'search-result-size'        => '$1 ({{PLURAL:$2|liafuan ida|liafuan $2}})',
+'search-section'            => '(seksaun $1)',
 'search-interwiki-caption'  => 'Projetu seluseluk sira',
 'search-mwsuggest-enabled'  => 'fó sujestaun',
 'search-mwsuggest-disabled' => 'la hatudu sujestaun',
@@ -474,20 +479,21 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'action-userrights-interwiki' => "edita priviléjiu uza-na'in iha wiki seluk sira",
 
 # Recent changes
-'nchanges'        => '$1 {{PLURAL:$1|diferensa|diferensa}}',
-'recentchanges'   => 'Mudansa foufoun sira',
-'rcshowhideminor' => "$1 muda ki-ki'ik",
-'rcshowhidebots'  => '$1 bot sira',
-'rcshowhideliu'   => '$1 ema rejista',
-'rcshowhideanons' => '$1 ema anónimu',
-'rcshowhidemine'  => "$1 ha'u-nia edita",
-'diff'            => 'diferensa',
-'hist'            => 'istória',
-'hide'            => 'Hamsumik',
-'show'            => 'Hatudu',
-'minoreditletter' => 'k',
-'newpageletter'   => 'F',
-'boteditletter'   => 'b',
+'nchanges'           => '$1 {{PLURAL:$1|diferensa|diferensa}}',
+'recentchanges'      => 'Mudansa foufoun sira',
+'rcshowhideminor'    => "$1 muda ki-ki'ik",
+'rcshowhidebots'     => '$1 bot sira',
+'rcshowhideliu'      => '$1 ema rejista',
+'rcshowhideanons'    => '$1 ema anónimu',
+'rcshowhidemine'     => "$1 ha'u-nia edita",
+'diff'               => 'diferensa',
+'hist'               => 'istória',
+'hide'               => 'Hamsumik',
+'show'               => 'Hatudu',
+'minoreditletter'    => 'k',
+'newpageletter'      => 'F',
+'boteditletter'      => 'b',
+'rc-enhanced-expand' => 'Hatudu detalle (presiza JavaScript)',
 
 # Recent changes linked
 'recentchangeslinked'         => 'Muda sira',
@@ -546,6 +552,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'nmembers'          => '$1 {{PLURAL:$1|membru|membru}}',
 'nrevisions'        => '$1 {{PLURAL:$1|versaun|versaun}}',
 'unusedcategories'  => "Kategoria sira-ne'ebé la uza",
+'prefixindex'       => 'Pájina hotu ho prefiksu',
 'shortpages'        => 'Pájina badak',
 'longpages'         => 'Pájina naruk',
 'listusers'         => "Lista uza-na'in",
@@ -605,16 +612,17 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'emailsend'       => 'Haruka',
 
 # Watchlist
-'watchlist'        => "Ha'u-nia lista hateke",
-'mywatchlist'      => "Ha'u-nia lista hateke",
-'watchlistfor'     => "('''$1''' nian)",
-'addedwatch'       => 'tau tan tiha ba lista hateke',
-'removedwatch'     => 'La hateke pájina ona',
-'removedwatchtext' => 'La hateke pájina "[[:$1]]" ona.',
-'watch'            => 'Hateke',
-'watchthispage'    => "Hateke pájina ne'e",
-'unwatch'          => 'La hateke ona',
-'wlshowlast'       => 'Hatudu $1 hora $2 loron ikus $3',
+'watchlist'         => "Ha'u-nia lista hateke",
+'mywatchlist'       => "Ha'u-nia lista hateke",
+'watchlistfor'      => "('''$1''' nian)",
+'addedwatch'        => 'tau tan tiha ba lista hateke',
+'removedwatch'      => 'La hateke pájina ona',
+'removedwatchtext'  => 'La hateke pájina "[[:$1]]" ona.',
+'watch'             => 'Hateke',
+'watchthispage'     => "Hateke pájina ne'e",
+'unwatch'           => 'La hateke ona',
+'watchlist-details' => '{{PLURAL:$1|Pájina ida (1)|Pájina $1}} iha Ita-nia "lista hateke" (la ho pájina diskusaun).',
+'wlshowlast'        => 'Hatudu $1 hora $2 loron ikus $3',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'Hateke...',
@@ -631,6 +639,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'excontentauthor'        => "testu iha pájina: '$1' (no ema ida de'it ne'ebé kontribui '[[Special:Contributions/$2|$2]]')",
 'exblank'                => 'pájina mamuk',
 'delete-legend'          => 'Halakon',
+'actioncomplete'         => 'operasaun remata',
 'deletedarticle'         => 'halakon "[[$1]]"',
 'dellogpage'             => 'Lista halakon',
 'deletionlog'            => 'lista halakon',
@@ -676,11 +685,13 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'blanknamespace' => '(Prinsipál)',
 
 # Contributions
-'contributions' => "Kontribuisaun uza-na'in",
-'mycontris'     => "Ha'u-nia kontribuisaun",
-'uctop'         => '(versaun atuál)',
-'month'         => 'Fulan (ho molok):',
-'year'          => 'Tinan (ho molok):',
+'contributions'       => "Kontribuisaun uza-na'in",
+'contributions-title' => 'Kontribuisaun "$1" nian',
+'mycontris'           => "Ha'u-nia kontribuisaun",
+'contribsub2'         => 'Ba $1 ($2)',
+'uctop'               => '(versaun atuál)',
+'month'               => 'Fulan (ho molok):',
+'year'                => 'Tinan (ho molok):',
 
 'sp-contributions-newbies'  => "Hatudu de'it kontribuisaun uza-na'in foun sira-nia",
 'sp-contributions-talk'     => 'diskusaun',
@@ -693,30 +704,32 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'whatlinkshere-title'     => 'Pájina sira ne\'ebé bá "$1".',
 'whatlinkshere-page'      => 'Pájina:',
 'linkshere'               => "Pájina sira ne'e link ba '''[[:$1]]''':",
+'isimage'                 => 'ligasaun ba imajen ida',
 'whatlinkshere-prev'      => '{{PLURAL:$1|oinmai|oinmai $1}}',
 'whatlinkshere-next'      => '{{PLURAL:$1|molok|molok $1}}',
 'whatlinkshere-links'     => '← ligasaun',
 'whatlinkshere-hidelinks' => '$1 ligasaun',
 
 # Block/unblock
-'blockip'                 => "Blokeiu uza-na'in",
-'blockip-legend'          => "Blokeiu uza-na'in",
-'ipaddress'               => 'Diresaun IP:',
-'ipbreason'               => 'Motivu:',
-'ipbreasonotherlist'      => 'Motivu seluk',
-'ipbsubmit'               => "Blokeiu uza-na'in ne'e",
-'ipbother'                => 'Tempu seluk:',
-'ipboptions'              => '2 hours:2 hours,1 loron:1 day,3 Loron:3 days,1 semana:1 week,2 semana:2 weeks,1 fulan:1 month,3 fulan:3 months,6 fulan:6 months,1 tinan:1 year,infinite:infinite',
-'ipbotheroption'          => 'seluk',
-'ipblocklist'             => 'Ema anónimu no rejista maka la bele edita',
-'ipblocklist-username'    => "Naran uza-na'in ka IP:",
-'ipblocklist-submit'      => 'Buka',
-'anononlyblock'           => "ema anónimu de'it",
-'blocklink'               => 'blokeiu',
-'unblocklink'             => 'la blokeiu',
-'contribslink'            => 'kontribuisaun',
-'block-log-flags-noemail' => 'korreiu eletróniku blokeiu',
-'ipb_already_blocked'     => 'Ema ruma blokeiu "$1" tiha ona',
+'blockip'                  => "Blokeiu uza-na'in",
+'blockip-legend'           => "Blokeiu uza-na'in",
+'ipaddress'                => 'Diresaun IP:',
+'ipbreason'                => 'Motivu:',
+'ipbreasonotherlist'       => 'Motivu seluk',
+'ipbsubmit'                => "Blokeiu uza-na'in ne'e",
+'ipbother'                 => 'Tempu seluk:',
+'ipboptions'               => '2 hours:2 hours,1 loron:1 day,3 Loron:3 days,1 semana:1 week,2 semana:2 weeks,1 fulan:1 month,3 fulan:3 months,6 fulan:6 months,1 tinan:1 year,infinite:infinite',
+'ipbotheroption'           => 'seluk',
+'ipblocklist'              => "Uza-na'in sira-ne'ebé la bele edita",
+'ipblocklist-username'     => "Naran uza-na'in ka IP:",
+'ipblocklist-submit'       => 'Buka',
+'anononlyblock'            => "ema anónimu de'it",
+'blocklink'                => 'blokeiu',
+'unblocklink'              => 'la blokeiu',
+'contribslink'             => 'kontribuisaun',
+'block-log-flags-nocreate' => 'la bele kria konta foun',
+'block-log-flags-noemail'  => 'korreiu eletróniku blokeiu',
+'ipb_already_blocked'      => 'Ema ruma blokeiu "$1" tiha ona',
 
 # Move page
 'move-page'               => 'Book $1',
@@ -764,8 +777,10 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'tooltip-ca-protect'             => "Proteje pájina ne'e",
 'tooltip-ca-delete'              => "Halakon pájina ne'e",
 'tooltip-ca-move'                => "Book pájina ne'e",
-'tooltip-ca-watch'               => "Tau tan pájina ne'e ba ó-nia lista hateke",
+'tooltip-ca-watch'               => 'Tau pájina ne\'e ba Ita-nia "lista hateke"',
+'tooltip-ca-unwatch'             => 'Hasai pájina ne\'e husi Ita-nia "lista hateke"',
 'tooltip-search'                 => 'Buka iha {{SITENAME}}',
+'tooltip-search-go'              => "Bá pájina ho naran ne'e (se iha)",
 'tooltip-p-logo'                 => 'Pájina Mahuluk',
 'tooltip-n-mainpage'             => 'Vizita Pájina Mahuluk',
 'tooltip-n-mainpage-description' => 'Vizita Pájina Mahuluk',
@@ -779,12 +794,13 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'tooltip-t-upload'               => 'Tau iha arkivu laran',
 'tooltip-t-specialpages'         => 'Lista pájina espesiál hotu nian',
 'tooltip-t-print'                => "Versaun pájina ne'e nian ba imprime/prin",
+'tooltip-ca-nstab-main'          => 'Haree konteúdu pájina nian',
 'tooltip-ca-nstab-user'          => "Haree pájina uza-na'in",
 'tooltip-ca-nstab-special'       => "Ne'e pájina espesiál – Ita la bele edita",
 'tooltip-ca-nstab-project'       => 'Haree pájina projetu nian',
 'tooltip-ca-nstab-category'      => 'Lee pájina kategoria',
 'tooltip-minoredit'              => "Marka ne'e hanesan muda ki'ik",
-'tooltip-watch'                  => "Tau tan pájina ne'e ba ó-nia lista hateke",
+'tooltip-watch'                  => 'Tau pájina ne\'e ba Ita-nia "lista hateke"',
 
 # Attribution
 'lastmodifiedatby' => "$3 filak ikus pájina ne'e iha $1, $2.",
